pub struct Variable;Expand description
Variable mode 8-16 bit transfer sizes Can do per data word setting adjustments using the DMA stream 32-bits store:
- data (8-16 bits)
- pcs (CS) (4 bits)
- lastxfer (1 bit)
Not as efficient RAM/flash wise, but fewer interrupts and polling loops are required as PDC can handle entire sequences talking to many SPI chips.
See section: 33.7.3.6 https://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-11100-32-bit%20Cortex-M4-Microcontroller-SAM4S_Datasheet.pdf